@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * getBaseSubject() code adapted from imap-base-subject.c (Dovecot 1.2)
  *   Original code released under the LGPL-2.1
@@ -11,7 +11,7 @@
  *
  * @category  Horde
  * @copyright 2002-2008 Timo Sirainen
- * @copyright 2008-2013 Horde LLC
+ * @copyright 2008-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -23,7 +23,7 @@
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
  * @copyright 2002-2008 Timo Sirainen
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -54,10 +54,6 @@ class Horde_Imap_Client_Data_BaseSubject
         // Rule 1b: Remove superfluous whitespace.
         $str = preg_replace("/[\t\r\n ]+/", ' ', $str);
 
-        if (!strlen($str)) {
-            $this->_subject = '';
-        }
-
         do {
             /* (2) Remove all trailing text of the subject that matches the
              * the subj-trailer ABNF, repeat until no more matches are
@@ -82,7 +78,7 @@ class Horde_Imap_Client_Data_BaseSubject
              * subj-fwd-trl and repeat from step (2). */
         } while ($this->_removeSubjFwdHdr($str));
 
-        $this->_subject = $str;
+        $this->_subject = strval($str);
     }
 
     /**
@@ -129,10 +125,8 @@ class Horde_Imap_Client_Data_BaseSubject
 
         if (stripos($str, 're', $i) === 0) {
             $i += 2;
-        } elseif (stripos($str, 'fwd', $i) === 0) {
-            $i += 3;
         } elseif (stripos($str, 'fw', $i) === 0) {
-            $i += 2;
+            $i += (stripos($str, 'fwd', $i) === 0) ? 3 : 2;
         } else {
             return $ret;
         }
