@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,11 +16,12 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2013 Horde LLC
+ * @copyright 2012-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Exception_NoSupportPop3 extends Horde_Imap_Client_Exception
+class Horde_Imap_Client_Exception_NoSupportPop3
+extends Horde_Imap_Client_Exception
 {
     /**
      * Constructor.
@@ -30,9 +31,10 @@ class Horde_Imap_Client_Exception_NoSupportPop3 extends Horde_Imap_Client_Except
     public function __construct($feature)
     {
         parent::__construct(
-            sprintf(Horde_Imap_Client_Translation::t("%s not supported on POP3 servers."), $feature),
+            Horde_Imap_Client_Translation::r("%s not supported on POP3 servers."),
             self::NOT_SUPPORTED
         );
+        $this->messagePrintf(array($feature));
     }
 
 }
