@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -16,13 +16,15 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2011-2013 Horde LLC
+ * @copyright 2011-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  *
  * @property-read boolean $all  Does this represent an ALL message set?
  * @property-read array $ids  The list of IDs.
  * @property-read boolean $largest  Does this represent the largest ID in use?
+ * @property-read string $max  The largest ID (@since 2.20.0).
+ * @property-read string $min  The smallest ID (@since 2.20.0).
  * @property-read string $range_string  Generates a range string consisting of
  *                                      all messages between begin and end of
  *                                      ID list.
@@ -38,7 +40,9 @@
  */
 class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
 {
-    /* "Special" representation constants. */
+    /**
+     * "Special" representation constants.
+     */
     const ALL = "\01";
     const SEARCH_RES = "\02";
     const LARGEST = "\03";
@@ -99,14 +103,21 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
         case 'largest':
             return ($this->_ids === self::LARGEST);
 
+        case 'max':
+            $this->sort();
+            return end($this->_ids);
+
+        case 'min':
+            $this->sort();
+            return reset($this->_ids);
+
         case 'range_string':
             if (!count($this)) {
                 return '';
             }
 
-            $this->sort();
-            $min = reset($this->_ids);
-            $max = end($this->_ids);
+            $min = $this->min;
+            $max = $this->max;
 
             return ($min == $max)
                 ? $min
@@ -154,21 +165,22 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
             if (is_string($ids) &&
                 in_array($ids, array(self::ALL, self::SEARCH_RES, self::LARGEST))) {
                 $this->_ids = $ids;
-                $this->_sorted = false;
-                return;
-            }
-
-            if ($add = $this->_resolveIds($ids)) {
-                $this->_ids = is_array($this->_ids)
-                    ? array_merge($this->_ids, $add)
-                    : $add;
+            } elseif ($add = $this->_resolveIds($ids)) {
+                if (is_array($this->_ids) && !empty($this->_ids)) {
+                    foreach ($add as $val) {
+                        $this->_ids[] = $val;
+                    }
+                } else {
+                    $this->_ids = $add;
+                }
                 if (!$this->duplicates) {
                     $this->_ids = (count($this->_ids) > 25000)
                         ? array_unique($this->_ids)
                         : array_keys(array_flip($this->_ids));
                 }
-                $this->_sorted = false;
             }
+
+            $this->_sorted = (count($this->_ids) === 1);
         }
     }
 
@@ -209,16 +221,26 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
     }
 
     /**
-     * Sorts the IDs numerically.
+     * Sorts the IDs.
      */
     public function sort()
     {
         if (!$this->_sorted && is_array($this->_ids)) {
-            sort($this->_ids, SORT_NUMERIC);
+            $this->_sort($this->_ids);
             $this->_sorted = true;
         }
     }
 
+    /**
+     * Sorts the IDs numerically.
+     *
+     * @param array $ids  The array list.
+     */
+    protected function _sort(&$ids)
+    {
+        sort($ids, SORT_NUMERIC);
+    }
+
     /**
      * Split the sequence string at an approximate length.
      *
@@ -236,8 +258,8 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
         $out = array();
 
         do {
-            $out[] = stream_get_contents($id->stream, $length) . $id->getToChar(',');
-        } while (!feof($id->stream));
+            $out[] = $id->substring(0, $length) . $id->getToChar(',');
+        } while (!$id->eof());
 
         return $out;
     }
@@ -283,8 +305,8 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
 
         $in = $this->_ids;
 
-        if ($sort) {
-            sort($in, SORT_NUMERIC);
+        if ($sort && !$this->_sorted) {
+            $this->_sort($in);
         }
 
         $first = $last = array_shift($in);
@@ -361,7 +383,7 @@ class Horde_Imap_Client_Ids implements Countable, Iterator, Serializable
     {
         return is_array($this->_ids)
             ? count($this->_ids)
-           : 0;
+            : 0;
     }
 
     /* Iterator methods. */
