@@ -107,7 +107,7 @@ class Horde_Imap_Client_Search_Query implements Serializable
      *
      * @param Horde_Imap_Client_Base $exts  The server object this query will
      *                                      be run on (@since 2.24.0), a
-     *                                      Hore_Imap_Client_Data_Capability
+     *                                      Horde_Imap_Client_Data_Capability
      *                                      object (@since 2.24.0), or the
      *                                      list of extensions present
      *                                      on the server (@deprecated).
@@ -122,6 +122,7 @@ class Horde_Imap_Client_Search_Query implements Serializable
      *   - query: (Horde_Imap_Client_Data_Format_List) The IMAP search
      *            command.
      *
+     * @throws Horde_Imap_Client_Data_Format_Exception
      * @throws Horde_Imap_Client_Exception_NoSupportExtension
      */
     public function build($exts = array())
@@ -147,10 +148,20 @@ class Horde_Imap_Client_Search_Query implements Serializable
             'exts_used' => array()
         );
         $cmds = &$temp['cmds'];
-        $charset = null;
+        $charset = $charset_cname = null;
         $exts_used = &$temp['exts_used'];
         $ptr = &$this->_search;
 
+        $charset_get = function($c) use (&$charset, &$charset_cname)
+        {
+            $charset = is_null($c)
+                ? 'US-ASCII'
+                : strval($c);
+            $charset_cname = ($charset === 'US-ASCII')
+                ? 'Horde_Imap_Client_Data_Format_Astring'
+                : 'Horde_Imap_Client_Data_Format_Astring_Nonascii';
+        };
+
         if (isset($ptr['new'])) {
             $this->_addFuzzy(!empty($ptr['newfuzzy']), $temp);
             if ($ptr['new']) {
@@ -210,10 +221,11 @@ class Horde_Imap_Client_Search_Query implements Serializable
                         new Horde_Imap_Client_Data_Format_Astring($val['header'])
                     ));
                 }
-                $cmds->add(new Horde_Imap_Client_Data_Format_Astring(isset($val['text']) ? $val['text'] : ''));
-                $charset = is_null($this->_charset)
-                    ? 'US-ASCII'
-                    : $this->_charset;
+
+                $charset_get($this->_charset);
+                $cmds->add(
+                    new $charset_cname(isset($val['text']) ? $val['text'] : '')
+                );
             }
         }
 
@@ -224,15 +236,12 @@ class Horde_Imap_Client_Search_Query implements Serializable
                 if (!empty($val['not'])) {
                     $cmds->add('NOT');
                 }
+
+                $charset_get($this->_charset);
                 $cmds->add(array(
                     $val['type'],
-                    new Horde_Imap_Client_Data_Format_Astring($val['text'])
+                    new $charset_cname($val['text'])
                 ));
-                if (is_null($charset)) {
-                    $charset = is_null($this->_charset)
-                        ? 'US-ASCII'
-                        : $this->_charset;
-                }
             }
         }
 
