@@ -27,6 +27,13 @@
  */
 class Horde_Imap_Client_Socket_ClientSort
 {
+    /**
+     * Collator object to use for sotring.
+     *
+     * @var Collator
+     */
+    protected $_collator;
+
     /**
      * Socket object.
      *
@@ -42,6 +49,10 @@ class Horde_Imap_Client_Socket_ClientSort
     public function __construct(Horde_Imap_Client_Socket $socket)
     {
         $this->_socket = $socket;
+
+        if (class_exists('Collator')) {
+            $this->_collator = new Collator(null);
+        }
     }
 
     /**
@@ -84,6 +95,10 @@ class Horde_Imap_Client_Socket_ClientSort
                 $query->envelope();
                 break;
 
+            case Horde_Imap_Client::SORT_SEQUENCE:
+                $query->seq();
+                break;
+
             case Horde_Imap_Client::SORT_SIZE:
                 $query->size();
                 break;
@@ -168,10 +183,6 @@ class Horde_Imap_Client_Socket_ClientSort
             foreach ($slices_list as $slice_start => $slice) {
                 $sorted = array();
 
-                if ($reverse) {
-                    $slice = array_reverse($slice);
-                }
-
                 switch ($val) {
                 case Horde_Imap_Client::SORT_SEQUENCE:
                     /* There is no requirement that IDs be returned in
@@ -195,19 +206,13 @@ class Horde_Imap_Client_Socket_ClientSort
                         : 'to';
 
                     foreach ($slice as $num) {
-                        $env = $fetch_res[$num]->getEnvelope();
-
-                        if (empty($env->$field)) {
-                            $sorted[$num] = null;
-                        } else {
-                            $addr_ob = reset($env->$field);
-                            if (is_null($sorted[$num] = $addr_ob->personal)) {
-                                $sorted[$num] = $addr_ob->mailbox;
-                            }
-                        }
+                        $ob = $fetch_res[$num]->getEnvelope()->$field;
+                        $sorted[$num] = ($addr_ob = $ob[0])
+                            ? $addr_ob->personal ?: $addr_ob->mailbox
+                            : null;
                     }
 
-                    asort($sorted, SORT_LOCALE_STRING);
+                    $this->_sortString($sorted);
                     break;
 
                 case Horde_Imap_Client::SORT_CC:
@@ -227,7 +232,8 @@ class Horde_Imap_Client_Socket_ClientSort
                             ? $tmp[0]->mailbox
                             : null;
                     }
-                    asort($sorted, SORT_LOCALE_STRING);
+
+                    $this->_sortString($sorted);
                     break;
 
                 case Horde_Imap_Client::SORT_ARRIVAL:
@@ -246,13 +252,18 @@ class Horde_Imap_Client_Socket_ClientSort
                     foreach ($slice as $num) {
                         $sorted[$num] = strval(new Horde_Imap_Client_Data_BaseSubject($fetch_res[$num]->getEnvelope()->subject));
                     }
-                    asort($sorted, SORT_LOCALE_STRING);
+
+                    $this->_sortString($sorted);
                     break;
                 }
 
                 // At this point, keys of $sorted are sequence/UID and values
                 // are the sort strings
                 if (!empty($sorted)) {
+                    if ($reverse) {
+                        $sorted = array_reverse($sorted, true);
+                    }
+
                     if (count($sorted) === count($res)) {
                         $res = array_keys($sorted);
                     } else {
@@ -262,11 +273,13 @@ class Horde_Imap_Client_Socket_ClientSort
                     // Check for ties.
                     $last = $start = null;
                     $i = 0;
+                    $todo = array();
                     reset($sorted);
+
                     while (list($k, $v) = each($sorted)) {
                         if (is_null($last) || ($last != $v)) {
                             if ($i) {
-                                $slices[array_search($start, $res)] = array_slice($sorted, array_search($start, $sorted), $i + 1);
+                                $todo[] = array($start, $i);
                                 $i = 0;
                             }
                             $last = $v;
@@ -276,7 +289,18 @@ class Horde_Imap_Client_Socket_ClientSort
                         }
                     }
                     if ($i) {
-                        $slices[array_search($start, $res)] = array_slice($sorted, array_search($start, $sorted), $i + 1);
+                        $todo[] = array($start, $i);
+                    }
+
+                    foreach ($todo as $v) {
+                        $slices[array_search($v[0], $res)] = array_keys(
+                            array_slice(
+                                $sorted,
+                                array_search($v[0], $sorted),
+                                $v[1] + 1,
+                                true
+                            )
+                        );
                     }
                 }
             }
@@ -333,4 +357,18 @@ class Horde_Imap_Client_Socket_ClientSort
         array_walk($a, function(&$v, $k) { $v = $v[0]; });
     }
 
+    /**
+     * Sort an array of strings based on current locale.
+     *
+     * @param array &$sorted  Array of strings.
+     */
+    protected function _sortString(&$sorted)
+    {
+        if (empty($this->_collator)) {
+            asort($sorted, SORT_LOCALE_STRING);
+        } else {
+            $this->_collator->asort($sorted, Collator::SORT_STRING);
+        }
+    }
+
 }
