@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -20,30 +20,38 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @internal
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Socket_Connection_Pop3 extends Horde\Socket\Client
+class Horde_Imap_Client_Socket_Connection_Pop3
+extends Horde_Imap_Client_Socket_Connection_Base
 {
+    /**
+     */
+    protected $_protocol = 'pop3';
+
     /**
      * Writes data to the POP3 output stream.
      *
-     * @param string $data  String data.
+     * @param string $data    String data.
+     * @param boolean $debug  Output line to debug?
      *
      * @throws Horde_Imap_Client_Exception
      */
-    public function write($data)
+    public function write($data, $debug = true)
     {
         if (fwrite($this->_stream, $data . "\r\n") === false) {
             throw new Horde_Imap_Client_Exception(
-                Horde_Imap_Client_Translation::t("Server write error."),
+                Horde_Imap_Client_Translation::r("Server write error."),
                 Horde_Imap_Client_Exception::SERVER_WRITEERROR
             );
         }
 
-        $this->_params['debug']->client($data);
+        if ($debug) {
+            $this->_params['debug']->client($data);
+        }
     }
 
     /**
@@ -57,17 +65,19 @@ class Horde_Imap_Client_Socket_Connection_Pop3 extends Horde\Socket\Client
     {
         if (feof($this->_stream)) {
             $this->close();
-            $this->_params['debug']->info("ERROR: Server closed the connection.");
+            $this->_params['debug']->info(
+                'ERROR: Server closed the connection.'
+            );
             throw new Horde_Imap_Client_Exception(
-                Horde_Imap_Client_Translation::t("Server closed the connection unexpectedly."),
+                Horde_Imap_Client_Translation::r("Server closed the connection unexpectedly."),
                 Horde_Imap_Client_Exception::DISCONNECT
             );
         }
 
         if (($read = fgets($this->_stream)) === false) {
-            $this->_params['debug']->info("ERROR: read/timeout error.");
+            $this->_params['debug']->info('ERROR: read/timeout error.');
             throw new Horde_Imap_Client_Exception(
-                Horde_Imap_Client_Translation::t("Error when communicating with the mail server."),
+                Horde_Imap_Client_Translation::r("Error when communicating with the mail server."),
                 Horde_Imap_Client_Exception::SERVER_READERROR
             );
         }
