@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -20,13 +20,21 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @internal
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
-class Horde_Imap_Client_Socket_Connection_Socket extends Horde\Socket\Client
+class Horde_Imap_Client_Socket_Connection_Socket
+extends Horde_Imap_Client_Socket_Connection_Base
 {
+    /**
+     * If false, does not outpt the current line of client output to debug.
+     *
+     * @var boolean
+     */
+    public $client_debug = true;
+
     /**
      * Sending buffer.
      *
@@ -46,16 +54,21 @@ class Horde_Imap_Client_Socket_Connection_Socket extends Horde\Socket\Client
     {
         if ($eol) {
             $buffer = $this->_buffer;
+            $debug = $this->client_debug;
             $this->_buffer = '';
 
+            $this->client_debug = true;
+
             if (fwrite($this->_stream, $buffer . $data . ($eol ? "\r\n" : '')) === false) {
                 throw new Horde_Imap_Client_Exception(
-                    Horde_Imap_Client_Translation::t("Server write error."),
+                    Horde_Imap_Client_Translation::r("Server write error."),
                     Horde_Imap_Client_Exception::SERVER_WRITEERROR
                 );
             }
 
-            $this->_params['debug']->client($buffer . $data);
+            if ($debug) {
+                $this->_params['debug']->client($buffer . $data);
+            }
         } else {
             $this->_buffer .= $data;
         }
@@ -74,22 +87,32 @@ class Horde_Imap_Client_Socket_Connection_Socket extends Horde\Socket\Client
     public function writeLiteral($data, $length, $binary = false)
     {
         $this->_buffer = '';
+        $success = false;
 
         if ($data instanceof Horde_Stream) {
             $data = $data->stream;
         }
 
-        rewind($data);
-        while (!feof($data)) {
-            if (fwrite($this->_stream, fread($data, 8192)) === false) {
-                throw new Horde_Imap_Client_Exception(
-                    Horde_Imap_Client_Translation::t("Server write error."),
-                    Horde_Imap_Client_Exception::SERVER_WRITEERROR
-                );
+        if (rewind($data)) {
+            $success = true;
+            while (!feof($data)) {
+                if ((($read_data = fread($data, 8192)) === false) ||
+                    (fwrite($this->_stream, $read_data) === false)) {
+                    $success = false;
+                    break;
+                }
             }
         }
 
-        if (!empty($this->_params['debugliteral'])) {
+        if (!$success) {
+            $this->client_debug = true;
+            throw new Horde_Imap_Client_Exception(
+                Horde_Imap_Client_Translation::r("Server write error."),
+                Horde_Imap_Client_Exception::SERVER_WRITEERROR
+            );
+        }
+
+        if ($this->client_debug && !empty($this->_params['debugliteral'])) {
             rewind($data);
             while (!feof($data)) {
                 $this->_params['debug']->raw(fread($data, 8192));
@@ -115,9 +138,11 @@ class Horde_Imap_Client_Socket_Connection_Socket extends Horde\Socket\Client
         do {
             if (feof($this->_stream)) {
                 $this->close();
-                $this->_params['debug']->info("ERROR: Server closed the connection.");
+                $this->_params['debug']->info(
+                    'ERROR: Server closed the connection.'
+                );
                 throw new Horde_Imap_Client_Exception(
-                    Horde_Imap_Client_Translation::t("Mail server closed the connection unexpectedly."),
+                    Horde_Imap_Client_Translation::r("Mail server closed the connection unexpectedly."),
                     Horde_Imap_Client_Exception::DISCONNECT
                 );
             }
@@ -174,9 +199,9 @@ class Horde_Imap_Client_Socket_Connection_Socket extends Horde\Socket\Client
         } while (true);
 
         if (!$got_data) {
-            $this->_params['debug']->info("ERROR: read/timeout error.");
+            $this->_params['debug']->info('ERROR: read/timeout error.');
             throw new Horde_Imap_Client_Exception(
-                Horde_Imap_Client_Translation::t("Error when communicating with the mail server."),
+                Horde_Imap_Client_Translation::r("Error when communicating with the mail server."),
                 Horde_Imap_Client_Exception::SERVER_READERROR
             );
         }
