@@ -64,6 +64,7 @@
  *   - RFC 3206: AUTH/SYS response codes
  *   - RFC 4616: AUTH=PLAIN
  *   - RFC 5034: POP3 SASL
+ *   - RFC 6856: UTF8, LANG
  * </pre>
  *
  * @author    Richard Heyes <richard@phpguru.org>
@@ -109,7 +110,7 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
 
         switch ($name) {
         case 'url':
-            $url->protocol = 'pop3';
+            $out->protocol = 'pop3';
             break;
         }
 
@@ -259,6 +260,18 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             }
 
             $auth_mech[] = 'USER';
+
+            /* Enable UTF-8 mode (RFC 6856). MUST occur after STLS is
+             * issued. */
+            if ($this->_capability('UTF8')) {
+                try {
+                    $this->_sendLine('UTF8');
+                    $this->_temp['utf8'] = true;
+                } catch (Horde_Imap_Client_Exception $e) {
+                    /* If server responds to UTF8 command with error,
+                     * fallback to legacy non-UTF8 behavior. */
+                }
+            }
         } else {
             $auth_mech = array($this->_init['authmethod']);
         }
@@ -398,11 +411,54 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
             break;
 
         case 'APOP':
+            /* If UTF8 (+ USER) is active, and non-ASCII exists, need to apply
+             * SASLprep to username/password. RFC 6856[2.2]. Reject if
+             * UTF8 (+ USER) is not supported and 8-bit characters exist. */
+            if (Horde_Mime::is8bit($username) ||
+                Horde_Mime::is8bit($password)) {
+                if (empty($this->_temp['utf8']) ||
+                    !$this->_capability('UTF8', 'USER') ||
+                    !class_exists('Horde_Stringprep')) {
+                    $error = true;
+                } else {
+                    Horde_Stringprep::autoload();
+                    $saslprep = new Znerol\Component\Stringprep\Profile\SASLprep();
+
+                    try {
+                        $username = $saslprep->apply($username, 'UTF-8', self::MODE_QUERY);
+                        $password = $saslprep->apply($password, 'UTF-8', self::MODE_STORE);
+                        $error = false;
+                    } catch (Znerol\Component\Stringprep\ProfileException $e) {
+                        $error = true;
+                    }
+                }
+
+                if ($error) {
+                    throw new Horde_Imap_Client_Exception(
+                        Horde_Imap_Client_Translation::r("Authentication failed."),
+                        Horde_Imap_Client_Exception::LOGIN_AUTHENTICATIONFAILED
+                    );
+                }
+            }
+
             // RFC 1939 [7]
-            $this->_sendLine('APOP ' . $username . ' ' . hash('md5', $this->_temp['pop3timestamp'] . $password));
+            $this->_sendLine('APOP ' . $username . ' ' .
+                hash('md5', $this->_temp['pop3timestamp'] . $password));
             break;
 
         case 'USER':
+            /* POP3 servers without UTF8 (+ USER) does not accept non-ASCII
+             * in USER/PASS. RFC 6856[2.2] */
+            if ((empty($this->_temp['utf8']) ||
+                 !$this->_capability('UTF8', 'USER')) &&
+                (Horde_Mime::is8bit($username) ||
+                 Horde_Mime::is8bit($password))) {
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Authentication failed."),
+                    Horde_Imap_Client_Exception::LOGIN_AUTHENTICATIONFAILED
+                );
+            }
+
             // RFC 1939 [7]
             $this->_sendLine('USER ' . $username);
             $this->_sendLine('PASS ' . $password, array(
@@ -453,7 +509,21 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected function _setLanguage($langs)
     {
-        throw new Horde_Imap_Client_Exception_NoSupportPop3('LANGUAGE extension');
+        // RFC 6856 [3]
+        if (!$this->_capability('LANG')) {
+            throw new Horde_Imap_Client_Exception_NoSupportPop3('LANGUAGE extension');
+        }
+
+        foreach ($langs as $val) {
+            try {
+                $this->_sendLine('LANG ' . $val);
+                $this->_temp['lang'] = $val;
+            } catch (Horde_Imap_Client_Exception $e) {
+                // Setting language failed - move on to next one.
+            }
+        }
+
+        return $this->_getLanguage(false);
     }
 
     /**
@@ -461,7 +531,34 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
      */
     protected function _getLanguage($list)
     {
-        throw new Horde_Imap_Client_Exception_NoSupportPop3('LANGUAGE extension');
+        // RFC 6856 [3]
+        if (!$this->_capability('LANG')) {
+            throw new Horde_Imap_Client_Exception_NoSupportPop3('LANGUAGE extension');
+        }
+
+        if (!$list) {
+            return isset($this->_temp['lang'])
+                ? $this->_temp['lang']
+                : null;
+        }
+
+        $langs = array();
+
+        try {
+            $res = $this->_sendLine('LANG', array(
+                'multiline' => 'array'
+            ));
+
+            foreach ($res['data'] as $val) {
+                $parts = explode(' ', $val);
+                $langs[] = $parts[0];
+                // $parts[1] - lanuage description (not used)
+            }
+        } catch (Horde_Imap_Client_Exception $e) {
+            // Ignore: language listing might fail. RFC 6856 [3.3]
+        }
+
+        return $langs;
     }
 
     /**
@@ -552,14 +649,11 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
         $uidl = $this->_capability('UIDL');
         if ($flags & Horde_Imap_Client::STATUS_UIDNEXT) {
             if ($uidl) {
-                $res = $this->_pop3Cache('uidl');
-                $res = end($res);
-                /* Increment the last character.  If it is 0x7f, then
-                 * add another character to UID. */
-                $ord = ord(substr($res, -1));
-                $ret['uidnext'] = (++$ord > 126)
-                    ? ($res . '!')
-                    : substr_replace($res, chr($ord), -1);
+                $ctx = hash_init((PHP_MINOR_VERSION >= 4) ? 'fnv132' : 'sha1');
+                foreach ($this->_pop3Cache('uidl') as $key => $val) {
+                    hash_update($ctx, '|' . $key . '|' . $val);
+                }
+                $ret['uidnext'] = hash_final($ctx);
             } else {
                 $res = $this->_pop3Cache('stat');
                 $ret['uidnext'] = $res['msgs'] + 1;
@@ -1284,6 +1378,13 @@ class Horde_Imap_Client_Socket_Pop3 extends Horde_Imap_Client_Base
                     case 'AUTH':
                         $errcode = Horde_Imap_Client_Exception::LOGIN_AUTHENTICATIONFAILED;
                         break;
+
+                    // RFC 6856 [5]
+                    case 'UTF8':
+                        /* This code can only be issued if we (as client) are
+                         * broken, so no need to handle since we should never
+                         * be broken. */
+                        break;
                     }
                 }
             } elseif (isset($read[1])) {
