@@ -10,14 +10,14 @@
  *    SVN revision 1757
  *  The RoundCube project is released under the GPL (version 2)
  *
- * Copyright 2008-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
  * @copyright 2000 Edmund Grimley Evans <edmundo@rano.org>
- * @copyright 2008-2013 Horde LLC
+ * @copyright 2008-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -28,7 +28,7 @@
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
  * @copyright 2000 Edmund Grimley Evans <edmundo@rano.org>
- * @copyright 2008-2013 Horde LLC
+ * @copyright 2008-2014 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -68,7 +68,7 @@ class Horde_Imap_Client_Utf7imap
      *
      * @var array
      */
-    private static $_mbstring = null;
+    protected static $_mbstring = null;
 
     /**
      * Convert a string from UTF7-IMAP to UTF-8.
@@ -124,7 +124,10 @@ class Horde_Imap_Client_Utf7imap
                         if ($ch < 0x80) {
                             /* Printable US-ASCII */
                             if ((0x20 <= $ch) && ($ch < 0x7f)) {
-                                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                                throw new Horde_Imap_Client_Exception(
+                                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                                );
                             }
                             $p .= chr($ch);
                         } else if ($ch < 0x800) {
@@ -149,11 +152,17 @@ class Horde_Imap_Client_Utf7imap
                     (($u7len > 2) &&
                      ($str[$i + 1] === '&') &&
                      ($str[$i + 2] !== '-'))) {
-                    throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                    throw new Horde_Imap_Client_Exception(
+                        Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                        Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                    );
                 }
             } elseif ((ord($u7) < 0x20) || (ord($u7) >= 0x7f)) {
                 /* Not printable US-ASCII */
-                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                );
             } else {
                 $p .= $u7;
             }
@@ -212,7 +221,10 @@ class Horde_Imap_Client_Utf7imap
                 $ch = $c;
                 $n = 0;
             } elseif ($c < 0xc2) {
-                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                );
             } elseif ($c < 0xe0) {
                 $ch = $c & 0x1f;
                 $n = 1;
@@ -229,11 +241,17 @@ class Horde_Imap_Client_Utf7imap
                 $ch = $c & 0x01;
                 $n = 5;
             } else {
-                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                );
             }
 
             if ($n > --$u8len) {
-                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                );
             }
 
             ++$i;
@@ -241,13 +259,19 @@ class Horde_Imap_Client_Utf7imap
             for ($j = 0; $j < $n; ++$j) {
                 $o = ord($str[$i + $j]);
                 if (($o & 0xc0) !== 0x80) {
-                    throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                    throw new Horde_Imap_Client_Exception(
+                        Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                        Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                    );
                 }
                 $ch = ($ch << 6) | ($o & 0x3f);
             }
 
             if (($n > 1) && !($ch >> ($n * 5 + 1))) {
-                throw new Horde_Imap_Client_Exception(Horde_Imap_Client_Translation::t("Error converting UTF7-IMAP string."), Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION);
+                throw new Horde_Imap_Client_Exception(
+                    Horde_Imap_Client_Translation::r("Error converting UTF7-IMAP string."),
+                    Horde_Imap_Client_Exception::UTF7IMAP_CONVERSION
+                );
             }
 
             $i += $n;
