@@ -25,13 +25,13 @@
  */
 class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
 {
-    static public $config;
+    public static $config;
 
-    static private $created;
-    static private $test_mbox;
-    static private $test_mbox_utf8;
+    private static $created;
+    private static $test_mbox;
+    private static $test_mbox_utf8;
 
-    static public function setUpBeforeClass()
+    public static function setUpBeforeClass()
     {
         $c = array_shift(self::$config);
 
@@ -53,7 +53,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
         );
     }
 
-    static public function tearDownAfterClass()
+    public static function tearDownAfterClass()
     {
         if (self::$created) {
             foreach (array(self::$test_mbox, self::$test_mbox_utf8) as $val) {
@@ -70,7 +70,17 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
 
     public function testPreLoginCommands()
     {
-        $c = self::$live->capability;
+        try {
+            $c = self::$live->capability;
+        } catch (Horde_Imap_Client_Exception $e) {
+            switch ($e->getCode()) {
+            case $e::SERVER_CONNECT:
+                $this->markTestSkipped('Could not connect to server');
+                break;
+            }
+
+            throw $e;
+        }
 
         $this->assertInstanceOf(
             'Horde_Imap_Client_Data_Capability',
@@ -366,8 +376,39 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     /**
      * @depends testCopyingEmailToUtf8Mailbox
      */
+    public function testAppendMessagesToUtf8Mailbox()
+    {
+        /* Use a different message than any currently living in test_mbox
+         * since some servers (Gmail) will de-duplicate and ignore the later
+         * move to that mailbox. */
+        $uid = self::$live->append(self::$test_mbox_utf8, array(
+            array(
+                'data' => file_get_contents(__DIR__ . '/../fixtures/remote5.txt')
+            )
+        ));
+
+        if (!($uid instanceof Horde_Imap_Client_Ids)) {
+            $this->fail('Append successful but UIDs not properly returned.');
+        }
+    }
+
+
+    /**
+     * @depends testAppendMessagesToUtf8Mailbox
+     */
     public function testDeletingMessageFromMailboxViaFlagAndExpunge()
     {
+        // Get status of test mailbox (should have 4 messages).
+        $status = self::$live->status(
+            self::$test_mbox,
+            Horde_Imap_Client::STATUS_MESSAGES
+        );
+
+        $this->assertEquals(
+            4,
+            $status['messages']
+        );
+
         // Flagging test e-mail 2 with the Deleted flag.
         self::$live->store(self::$test_mbox, array(
             'add' => array(Horde_Imap_Client::FLAG_DELETED),
@@ -380,17 +421,6 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
             array('ids' => new Horde_Imap_Client_Ids(1, true))
         );
 
-        // Get status of test mailbox (should have 4 messages).
-        $status = self::$live->status(
-            self::$test_mbox,
-            Horde_Imap_Client::STATUS_MESSAGES
-        );
-
-        $this->assertEquals(
-            4,
-            $status['messages']
-        );
-
         // Expunging mailbox (should remove test e-mail 2)
         self::$live->expunge(self::$test_mbox);
 
@@ -411,12 +441,12 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
      */
     public function testMoveMessage()
     {
-        // Move test e-mail 1 from utf-8 test mailbox to the test mailbox.
+        // Move test e-mail 2 from utf-8 test mailbox to the test mailbox.
         self::$live->copy(
             self::$test_mbox_utf8,
             self::$test_mbox,
             array(
-                'ids' => new Horde_Imap_Client_Ids(1, true),
+                'ids' => new Horde_Imap_Client_Ids(2, true),
                 'move' => true
             )
         );
@@ -425,34 +455,43 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     /**
      * @depends testMoveMessage
      */
-    public function testFlagMessageDeletedWithoutExpunging()
+    public function testOptimizedSearches()
     {
-        // Flagging test e-mail 3 with the Deleted flag.
-        self::$live->store(
+        // Searching test mailbox (should be optimized by using internal
+        // status instead).
+        $res = self::$live->search(
             self::$test_mbox,
+            new Horde_Imap_Client_Search_Query(),
             array(
-                'add' => array(Horde_Imap_Client::FLAG_DELETED),
-                'ids' => new Horde_Imap_Client_Ids(3, true)
+                'results' => array(Horde_Imap_Client::SEARCH_RESULTS_COUNT)
             )
         );
 
-        // Closing test mailbox without expunging.
-        self::$live->close();
-
-        // Get status of test mailbox (should have 4 messages).
-        $status = self::$live->status(
-            self::$test_mbox,
-            Horde_Imap_Client::STATUS_MESSAGES
-        );
-
         $this->assertEquals(
             4,
-            $status['messages']
+            $res['count']
+        );
+
+        // All messages are unseen
+        $query2 = new Horde_Imap_Client_Search_Query();
+        $query2->flag(Horde_Imap_Client::FLAG_SEEN, false);
+        $res = self::$live->search(
+            self::$test_mbox,
+            $query2,
+            array(
+                'results' => array(Horde_Imap_Client::SEARCH_RESULTS_COUNT)
+            )
+        );
+
+        $this->assertEquals(
+            4,
+            $res['count']
         );
     }
 
+
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testSimpleSearch()
     {
@@ -469,7 +508,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testSequenceNumberSearchReturn()
     {
@@ -496,60 +535,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
-     */
-    public function testOptimizedSearches()
-    {
-        // Searching test mailbox (should be optimized by using internal
-        // status instead).
-        $res = self::$live->search(
-            self::$test_mbox,
-            new Horde_Imap_Client_Search_Query(),
-            array(
-                'results' => array(Horde_Imap_Client::SEARCH_RESULTS_COUNT)
-            )
-        );
-
-        $this->assertEquals(
-            4,
-            $res['count']
-        );
-
-        // No messages are recent
-        $query = new Horde_Imap_Client_Search_Query();
-        $query->flag(Horde_Imap_Client::FLAG_RECENT);
-        $res = self::$live->search(
-            self::$test_mbox,
-            $query,
-            array(
-                'results' => array(Horde_Imap_Client::SEARCH_RESULTS_COUNT)
-            )
-        );
-
-        $this->assertEquals(
-            0,
-            $res['count']
-        );
-
-        // All messages are unseen
-        $query2 = new Horde_Imap_Client_Search_Query();
-        $query2->flag(Horde_Imap_Client::FLAG_SEEN, false);
-        $res = self::$live->search(
-            self::$test_mbox,
-            $query2,
-            array(
-                'results' => array(Horde_Imap_Client::SEARCH_RESULTS_COUNT)
-            )
-        );
-
-        $this->assertEquals(
-            4,
-            $res['count']
-        );
-    }
-
-    /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testMailboxSort()
     {
@@ -578,7 +564,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testMailboxThreadByReferences()
     {
@@ -639,7 +625,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testMailboxThreadByOrderedSubject()
     {
@@ -680,7 +666,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testSimpleFetch()
     {
@@ -717,7 +703,7 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
     }
 
     /**
-     * @depends testFlagMessageDeletedWithoutExpunging
+     * @depends testOptimizedSearches
      */
     public function testComplexFetch()
     {
@@ -868,6 +854,46 @@ class Horde_Imap_Client_Live_Imap extends Horde_Imap_Client_Live_Base
      * @depends testSimpleFetch
      * @depends testComplexFetch
      */
+    public function testFlagMessageDeletedWithoutExpunging()
+    {
+        // Flagging test e-mail 3 with the Deleted flag.
+        self::$live->store(
+            self::$test_mbox,
+            array(
+                'add' => array(Horde_Imap_Client::FLAG_DELETED),
+                'ids' => new Horde_Imap_Client_Ids(3, true)
+            )
+        );
+
+        // Get status of test mailbox (should have 4 messages).
+        // Gmail will auto-expunge, so skip the close() test.
+        $status = self::$live->status(
+            self::$test_mbox,
+            Horde_Imap_Client::STATUS_MESSAGES
+        );
+
+        if ($status['messages'] === 3) {
+            return;
+        }
+
+        // Closing test mailbox without expunging.
+        self::$live->close();
+
+        // Get status of test mailbox (should have 4 messages).
+        $status = self::$live->status(
+            self::$test_mbox,
+            Horde_Imap_Client::STATUS_MESSAGES
+        );
+
+        $this->assertEquals(
+            4,
+            $status['messages']
+        );
+    }
+
+    /**
+     * @depends testFlagMessageDeletedWithoutExpunging
+     */
     public function testExpungeMessagesWhileClosing()
     {
         // Re-open test mailbox READ-WRITE.
